Coverage for appr/models/kv/redis/__init__.py: 100%

# Coverage for appr/models/kv/redis/__init__.py : 100%

## 4 statements 4 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 | import os import redis REDIS_HOST = os.getenv("REDIS_HOST", "localhost") # @TODO redis-configuration redis_client = redis.StrictRedis(host=REDIS_HOST, port=6379, db=0)